@@ -6,8 +6,8 @@ from transurlvania.defaults import *
 urlpatterns = patterns('garfield.views',
     url(r'^$', 'landing', name='garfield_landing'),
     url(_(r'^the-president/$'), 'the_president', name='garfield_the_president'),
-    url(_(r'^the-cat/$'), 'comic_strip_list', name='garfield_the_cat'),
+    (_(r'^the-cat/$'), 'comic_strip_list', {}, 'garfield_the_cat'),
     url(_(r'^the-cat/(?:P<strip_id>\d+)/$'), 'comic_strip_detail',
             name='garfield_comic_strip_detail'),
-    url(r'^jim-davis/$', 'jim_davis', name='garfield_jim_davis'),
+    url(r'', include('garfield.extra_urls')),
 )
