@@ -8,7 +8,7 @@ admin.autodiscover()
 urlpatterns = lang_prefixed_patterns('garfield.views',
     url(r'^$', 'home'),
     url(r'^admin/', include(admin.site.urls)),
-    url(r'^garfield/', include('garfield.urls')),
+    (r'^garfield/', include('garfield.urls')),
     url(_(r'^about-us/$'), 'about_us', name='about_us'),
 )
 
